genestboost package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   genestboost.link_functions
   genestboost.loss_functions
   genestboost.utils
   genestboost.weak_learners


.. automodule:: genestboost
   :members:
   :undoc-members:
   :show-inheritance:
